@@ -34,7 +34,7 @@ class Orden(BaseModel):
     op_tc_clave_ord: types.TipoCuentaOrdenPago = None
     op_cuenta_ord: str = None
     op_rfc_curp_ord: str = None
-    op_ins_clave_ord: digits(3, 5) = types.ClaveOrdenanteOrdenPago.AMU
+    op_ins_clave_ord: digits(3, 5) = types.ClaveOrdenanteOrdenPago.AMU.value
     # destination info
     op_nom_ben: str = None
     op_tc_clave_ben: types.TipoCuentaOrdenPago = None
@@ -136,15 +136,13 @@ class Orden(BaseModel):
         return mensaje
 
     @classmethod
-    def parse_xml(cls, mensaje_element):
-        ordenpago = mensaje_element.find('ordenpago')
-
+    def parse_xml(cls, orden_element, categoria: types.CategoriaOrdenPago):
         orden_data = {
-            'id': ordenpago.attrib['Id'],
-            'categoria': mensaje_element.attrib['categoria'],
+            'id': orden_element.attrib['Id'],
+            'categoria': categoria,
         }
 
-        for element in ordenpago.getchildren():
+        for element in orden_element.getchildren():
             tag = to_snake_case(element.tag)
             if tag in cls.__fields__:
                 orden_data[tag] = element.text
